#**********************************************************************
#                 triangular_clock.tcl
#                 ====================
#                   Uwe Berger; 2012
#
# http://pi.physik.uni-bonn.de/~pretz/uhr_loci/jpretz_joma_binary_clock.htm
#
#
# ---------
# Have fun!
#
#**********************************************************************
package require Tk

set gvar(led_dm)	40
set gvar(led_dx)	5
set gvar(dx)		[expr 5*($gvar(led_dm)+$gvar(led_dx)) + $gvar(led_dx)]
set gvar(dy)		$gvar(dx)
set gvar(color_off)		gray10
set gvar(color_on)		gray10
set gvar(color_on_am)	green
set gvar(color_on_pm)	red
set gvar(h)			0
set gvar(m)			0
set gvar(old_m)		60

#***************************
proc clear_leds {} {
	global gvar
	.clock itemconfigure led -fill $gvar(color_off) -outline $gvar(color_off)
}

#***************************
proc set_line {z d} {
	global gvar
	if {[expr $gvar(m)/$d]} {
		for {set i 0} {$i < [expr $gvar(m)/$d]} {incr i} {
			.clock itemconfigure z$z$i -fill $gvar(color_on) -outline $gvar(color_on)
		}
		set gvar(m) [expr $gvar(m) - $i*$d]
	}
}

#***************************
proc takt {} {
	global gvar
	# Uhrzeit ermitteln (wir brauchen nur Stunde und Minute)
	set gvar(m) [scan [clock format [clock seconds] -format %M] %d]
	set gvar(h) [scan [clock format [clock seconds] -format %H] %d]
	# hat sich die Minute geaendert, dann Zeit neu anzeigen...
	if {$gvar(old_m) != $gvar(m)} {
		set gvar(old_m) $gvar(m)
		clear_leds		
		if {$gvar(h) < 12} {
			set gvar(color_on) $gvar(color_on_am)
		} else {
			set gvar(color_on) $gvar(color_on_pm)
			set gvar(h) [expr $gvar(h) - 12]
		}
		# in Insgesamt-Minuten umrechnen
		set gvar(m) [expr $gvar(h)*60+$gvar(m)]
		# 1.Zeile: x*6h (360min)
		set_line 1 360
		# 2.Zeile: x*2h (120min)
		set_line 2 120
		# 3.Zeile: x*30min
		set_line 3 30
		# 4.Zeile: x*6min
		set_line 4 6
		# 5.Zeile: x*1min
		set_line 5 1
	}
	# Prozedur nach 1 Sekunde neu aufrufen	
	after 1000 takt
}

#***************************
proc gui {} {
	global gvar pi
	# Fenster generieren
	wm title . "Triangular Clock" 
	wm resizable . 0 0
	canvas	.clock -width $gvar(dx) -height $gvar(dy) -bg black -bd 0
	pack .clock 
	# LEDs zeichnen
	for {set i 1} {$i < 6} {incr i} {
	 set ox [expr $gvar(dx)/2-($i*($gvar(led_dm)+$gvar(led_dx))/2)+$gvar(led_dx)/2]
	 for {set j 0} {$j < $i} {incr j} {
		.clock create oval 	[expr $ox + $j*($gvar(led_dx)+$gvar(led_dm))]\
							[expr $i*$gvar(led_dx) + ($i-1) * $gvar(led_dm)]\
							[expr $ox + $j*($gvar(led_dx)+$gvar(led_dm))+$gvar(led_dm)]\
							[expr $i*$gvar(led_dx) + ($i-1) * $gvar(led_dm)+$gvar(led_dm)]\
							-outline $gvar(color_off)\
							-fill $gvar(color_off)\
							-tags [list z$i z$i$j led]
	 }
	}
}

#***************************
#***************************
#***************************
gui
takt
